@@ -74,8 +74,8 @@ class BaseCommand(asyncio.Future, StatusMixIn[CommandStatus], Generic[Actor_co])
         command_id: Union[int, str] = 0,
         consumer_id: Union[int, str] = 0,
         actor: Optional[Actor_co] = None,
-        parent: BaseCommand = None,
-        status_callback: Callable[[CommandStatus], Any] = None,
+        parent: Optional[BaseCommand[Actor_co]] = None,
+        status_callback: Optional[Callable[[CommandStatus], Any]] = None,
         call_now: bool = False,
         default_keyword: str = "text",
         loop: Optional[asyncio.AbstractEventLoop] = None,
