@@ -23,7 +23,7 @@ from aiormq.types import DeliveredMessage
 from pamqp.header import ContentHeader
 
 import clu
-from clu.actor import AMQPActor, JSONActor
+from clu.actor import AMQPBaseActor, TCPBaseActor
 from clu.command import Command
 from clu.legacy.actor import LegacyActor
 
@@ -40,7 +40,7 @@ else:
 __all__ = ["MockReply", "MockReplyList", "setup_test_actor"]
 
 
-class MockedActor(JSONActor, LegacyActor, AMQPActor):
+class MockedActor(TCPBaseActor, LegacyActor, AMQPBaseActor):
     invoke_mock_command: Any
     mock_replies: List[MockReply]
 
@@ -207,7 +207,7 @@ async def setup_test_actor(actor: T, user_id: int = 1) -> T:
             )
             return self.new_command(message, ack=False)
 
-    actor.start = CoroutineMock(return_value=actor)
+    actor.start = CoroutineMock(return_value=actor)  # type: ignore
 
     # Adds an invoke_mock_command method.
     # We use types.MethodType to bind a method to an existing instance
